/**
 * Return a string representation of an object, including its properties and nested objects, with customizable options.
 *
 * Echos the value of a value. Try to print the value out
 * in the best way possible given the different types.
 *
 * @param {*} obj - The object to inspect.
 * @param {object|boolean=} opts - Customizable options to control the behavior of the inspection. If it's a boolean, it sets the "showHidden" option.
 * @param {boolean=false} opts.showHidden - Whether to show non-enumerable properties of objects.
 * @param {number=2} opts.depth - How many levels deep nested objects are inspected.
 * @param {boolean=false} opts.colors - Whether to color the output.
 * @param {boolean=true} opts.customInspect - Whether to inspect custom inspect functions on objects.
 * @returns {string} The formatted string representing the object.
 */
export function inspect(obj: any, opts?: (object | boolean) | undefined, ...args: any[]): string;
export namespace inspect {
    namespace colors {
        const bold: number[];
        const italic: number[];
        const underline: number[];
        const inverse: number[];
        const white: number[];
        const grey: number[];
        const black: number[];
        const blue: number[];
        const cyan: number[];
        const green: number[];
        const magenta: number[];
        const red: number[];
        const yellow: number[];
    }
    namespace styles {
        export const special: string;
        export const number: string;
        export const boolean: string;
        export const undefined: string;
        const _null: string;
        export { _null as null };
        export const string: string;
        export const date: string;
        export const regexp: string;
    }
}
export default inspect;
